TODO
====

* alternatively either require `scrapy` dependency and use scrapy
  `TextResponse.text` or copy-paste relevant scrapy.utils code to this project
* current test data is very large. look into creating smaller synthetic test
  samples
